/*******************************************************************************
 * Copyright (c) 2008, 2023 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.wst.xsl.core.internal.util;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.content.IContentType;
import org.eclipse.core.runtime.content.IContentTypeManager;
import org.eclipse.wst.xsl.core.XSLCore;

/**
 * This is a general file utility class.
 * 
 * @author dcarver
 *
 */
public class FileUtil {

	/**
	 * Determines if a file is one of the valid XML content types.
	 * @param file The input IFile to check
	 * @return True if it is a XML file, false otherwise.
	 */
	public static boolean isXMLFile(IFile file)
	{
		IContentTypeManager contentTypeManager = Platform.getContentTypeManager();
		IContentType[] types = contentTypeManager.findContentTypesFor(file.getName());
		IContentType xmlContentType = contentTypeManager.getContentType("org.eclipse.core.runtime.xml"); //$NON-NLS-1$
		IContentType illformedXML = contentTypeManager.getContentType("org.eclipse.wst.xml.core.xmlsource"); //$NON-NLS-1$
		for (IContentType contentType : types)
		{
			if (contentType.isKindOf(xmlContentType) || contentType.isKindOf(illformedXML))
			{
				return true;
			}
		}
		return false;
	}

	/**
	 * Determines if a file is a XSLT File.
	 * @param file The input IFile to check.
	 * @return True if it is a XSLT file, false otherwise.
	 * 
	 */
	public static boolean isXSLFile(IFile file)
	{
		IContentTypeManager contentTypeManager = Platform.getContentTypeManager();
		IContentType xslContentType = contentTypeManager.getContentType(XSLCore.XSL_CONTENT_TYPE);
		IContentType[] types = contentTypeManager.findContentTypesFor(file.getName());
		for (IContentType contentType : types)
		{
			if (contentType.equals(xslContentType))
			{
				return true;
			}
		}
		return false;
	}

}
